@@ -88,10 +88,10 @@ int st_aiffseek(ft_t ft, st_size_t offset)
         new_offset += (channel_block - alignment);
     new_offset += aiff->dataStart;
 
-    ft->st_errno = st_seek(ft, new_offset, SEEK_SET);
+    ft->st_errno = st_seeki(ft, new_offset, SEEK_SET);
 
     if (ft->st_errno == ST_SUCCESS)
-        aiff->nsamples = ft->length - new_offset;
+        aiff->nsamples = ft->length - (new_offset / ft->info.size);
 
     return(ft->st_errno);
 }
@@ -203,12 +203,16 @@ int st_aiffstartread(ft_t ft)
                         st_readdw(ft, &blocksize);
                         chunksize -= 8;
                         ssndsize = chunksize;
+                        /* word-align chunksize in case it wasn't
+                         * done by writing application already.
+                         */
+                        chunksize += (chunksize % 2);
                         /* if can't seek, just do sound now */
                         if (!ft->seekable)
                                 break;
                         /* else, seek to end of sound and hunt for more */
                         seekto = st_tell(ft);
-                        st_seek(ft, chunksize, SEEK_CUR); 
+                        st_seeki(ft, chunksize, SEEK_CUR); 
                 }
                 else if (strncmp(buf, "MARK", 4) == 0) {
                         /* MARK chunk */
@@ -272,6 +276,10 @@ int st_aiffstartread(ft_t ft)
                 }
                 else if (strncmp(buf, "APPL", 4) == 0) {
                         st_readdw(ft, &chunksize);
+                        /* word-align chunksize in case it wasn't
+                         * done by writing application already.
+                         */
+                        chunksize += (chunksize % 2);
                         while(chunksize-- > 0)
                             st_readb(ft, (unsigned char *)&trash8);
                 }
@@ -354,7 +362,7 @@ int st_aiffstartread(ft_t ft)
         if (ft->seekable)
         {
                 if (seekto > 0)
-                        st_seek(ft, seekto, SEEK_SET);
+                        st_seeki(ft, seekto, SEEK_SET);
                 else
                 {
                         st_fail_errno(ft,ST_EOF,"AIFF: no sound data on input file");
@@ -415,7 +423,7 @@ int st_aiffstartread(ft_t ft)
 
         }
 
-        aiff->nsamples = ssndsize / ft->info.size;      /* leave out channels */
+        aiff->nsamples = ssndsize / ft->info.size;
 
         /* Cope with 'sowt' CD tracks as read on Macs */
         if (is_sowt)
@@ -522,7 +530,7 @@ static int textChunk(char **text, char *chunkDescription, ft_t ft)
     st_fail_errno(ft,ST_ENOMEM,"AIFF: Couldn't allocate %s header", chunkDescription);
     return(ST_EOF);
   }
-  if (st_read(ft, *text, 1, chunksize) != chunksize)
+  if (st_readbuf(ft, *text, 1, chunksize) != chunksize)
   {
     st_fail_errno(ft,ST_EOF,"AIFF: Unexpected EOF in %s header", chunkDescription);
     return(ST_EOF);
@@ -532,7 +540,7 @@ static int textChunk(char **text, char *chunkDescription, ft_t ft)
         {
                 /* Read past pad byte */
                 char c;
-                if (st_read(ft, &c, 1, 1) != 1)
+                if (st_readbuf(ft, &c, 1, 1) != 1)
                 {
                 st_fail_errno(ft,ST_EOF,"AIFF: Unexpected EOF in %s header", chunkDescription);
                         return(ST_EOF);
@@ -570,14 +578,14 @@ static int commentChunk(char **text, char *chunkDescription, ft_t ft)
       *text = (char *) malloc((size_t) totalCommentLength + 1);
     }
     else {
-      realloc(*text, (size_t) totalCommentLength + 1);
+      *text = realloc(*text, (size_t) totalCommentLength + 1);
     }
 
     if (*text == NULL) {
         st_fail_errno(ft,ST_ENOMEM,"AIFF: Couldn't allocate %s header", chunkDescription);
         return(ST_EOF);
     }
-    if (st_read(ft, *text + totalCommentLength - commentLength, 1, commentLength) != commentLength) {
+    if (st_readbuf(ft, *text + totalCommentLength - commentLength, 1, commentLength) != commentLength) {
         st_fail_errno(ft,ST_EOF,"AIFF: Unexpected EOF in %s header", chunkDescription);
         return(ST_EOF);
     }
@@ -586,7 +594,7 @@ static int commentChunk(char **text, char *chunkDescription, ft_t ft)
     if (commentLength % 2) {
         /* Read past pad byte */
         char c;
-        if (st_read(ft, &c, 1, 1) != 1) {
+        if (st_readbuf(ft, &c, 1, 1) != 1) {
             st_fail_errno(ft,ST_EOF,"AIFF: Unexpected EOF in %s header", chunkDescription);
             return(ST_EOF);
         }
@@ -598,7 +606,7 @@ static int commentChunk(char **text, char *chunkDescription, ft_t ft)
        int i;
        char c;
        for (i=0; i < chunksize - totalReadLength; i++ ) {
-               st_read(ft, &c, 1, 1);
+               st_readbuf(ft, &c, 1, 1);
        }
   }
   return(ST_SUCCESS);
@@ -630,7 +638,7 @@ int st_aiffstopread(ft_t ft)
         {
             while (! st_eof(ft)) 
             {
-                if (st_read(ft, buf, 1, 4) != 4)
+                if (st_readbuf(ft, buf, 1, 4) != 4)
                         break;
 
                 st_readdw(ft, &chunksize);
@@ -726,7 +734,7 @@ int st_aiffstopwrite(ft_t ft)
             st_fail_errno(ft,ST_EOF,"Non-seekable file.");
             return(ST_EOF);
         }
-        if (st_seek(ft, 0L, SEEK_SET) != 0)
+        if (st_seeki(ft, 0L, SEEK_SET) != 0)
         {
                 st_fail_errno(ft,errno,"can't rewind output file to rewrite AIFF header");
                 return(ST_EOF);
@@ -876,7 +884,7 @@ static int aiffwriteheader(ft_t ft, st_size_t nframes)
 static double read_ieee_extended(ft_t ft)
 {
         char buf[10];
-        if (st_read(ft, buf, 1, 10) != 10)
+        if (st_readbuf(ft, buf, 1, 10) != 10)
         {
                 st_fail_errno(ft,ST_EOF,"EOF while reading IEEE extended number");
                 return(ST_EOF);
@@ -894,7 +902,7 @@ static void write_ieee_extended(ft_t ft, double x)
                 buf[0], buf[1], buf[2], buf[3], buf[4],
                 buf[5], buf[6], buf[7], buf[8], buf[9]);
         */
-        (void)st_write(ft, buf, 1, 10);
+        (void)st_writebuf(ft, buf, 1, 10);
 }
 
 
