@@ -41,7 +41,7 @@ int st_autostartread(ft_t ft)
          * file.  So we start checking for those filetypes first.
          */
         memset(header,0,4);
-        if (st_read(ft, header, 1, 4) == 4)
+        if (st_readbuf(ft, header, 1, 4) == 4)
         {
             /* Look for .snd or dns. header of AU files */
             if ((strncmp(header, ".snd", 4) == 0) ||
@@ -56,7 +56,7 @@ int st_autostartread(ft_t ft)
             else if (strncmp(header, "FORM", 4) == 0) 
             {
                 /* Need to read more data to see what type of FORM file */
-                if (st_read(ft, header, 1, 8) == 8)
+                if (st_readbuf(ft, header, 1, 8) == 8)
                 {
                     if (strncmp(header + 4, "AIFF", 4) == 0)
                         type = "aiff";
@@ -70,7 +70,7 @@ int st_autostartread(ft_t ft)
             }
             else if (strncmp(header, "RIFF", 4) == 0)
             {
-                if (st_read(ft, header, 1, 8) == 8)
+                if (st_readbuf(ft, header, 1, 8) == 8)
                 {
                     if (strncmp(header + 4, "WAVE", 4) == 0)
                         type = "wav";
@@ -78,7 +78,7 @@ int st_autostartread(ft_t ft)
             }
             else if (strncmp(header, "Crea", 4) == 0) 
             {
-                if (st_read(ft, header, 1, 15) == 15)
+                if (st_readbuf(ft, header, 1, 15) == 15)
                 {
                     if (strncmp(header, "tive Voice File", 15) == 0) 
                         type = "voc";
@@ -87,10 +87,10 @@ int st_autostartread(ft_t ft)
             else if (strncmp(header, "SOUN", 4) == 0)
             {
                 /* Check for SOUND magic header */
-                if (st_read(ft, header, 1, 1) == 1 && *header == 'D')
+                if (st_readbuf(ft, header, 1, 1) == 1 && *header == 'D')
                 {
                     /* Once we've found SOUND see if its smp or sndt */
-                    if (st_read(ft, header, 1, 12) == 12)
+                    if (st_readbuf(ft, header, 1, 12) == 12)
                     {
                         if (strncmp(header, " SAMPLE DATA", 12) == 0)
                             type = "smp";
@@ -107,7 +107,7 @@ int st_autostartread(ft_t ft)
             }
             else if (strncmp(header, "NIST", 4) == 0) 
             {
-                if (st_read(ft, header, 1, 3) == 3)
+                if (st_readbuf(ft, header, 1, 3) == 3)
                 {
                     if (strncmp(header, "_1A", 3) == 0) 
                         type = "sph";
@@ -115,7 +115,7 @@ int st_autostartread(ft_t ft)
             }
             else if (strncmp(header, "ALaw", 4) == 0)
             {
-                if (st_read(ft, header, 1, 11) == 11)
+                if (st_readbuf(ft, header, 1, 11) == 11)
                 {
                     if (strncmp(header, "SoundFile**", 11) == 0)
                     {
@@ -137,19 +137,19 @@ int st_autostartread(ft_t ft)
             loop = 61;
             while (loop--)
             {
-                if (st_read(ft, header, 1, 1) != 1)
+                if (st_readbuf(ft, header, 1, 1) != 1)
                     loop = 0;
             }
-            if (st_read(ft, header, 1, 4) == 4 && 
+            if (st_readbuf(ft, header, 1, 4) == 4 && 
                 strncmp(header, "FSSD", 4) == 0)
             {
                 loop = 63;
                 while (loop--)
                 {
-                    if (st_read(ft, header, 1, 1) != 1)
+                    if (st_readbuf(ft, header, 1, 1) != 1)
                         loop = 0;
                 }
-                if (st_read(ft, header, 1, 4) == 0 && 
+                if (st_readbuf(ft, header, 1, 4) == 0 && 
                     strncmp(header, "HCOM", 4) == 0)
                     type = "hcom";
             }
@@ -173,7 +173,8 @@ int st_autostartread(ft_t ft)
             type = NULL;
     }
 
-    ft->filetype = type;
+    free(ft->filetype);
+    ft->filetype = strdup(type);
     rc = st_gettype(ft); /* Change ft->h to the new format */
     if(rc != ST_SUCCESS)
     {
