@@ -94,8 +94,8 @@ static void collect_data(profdata_t data, chandata_t* chan) {
     PowerSpectrum(WINDOWSIZE, chan->window, out);
 
     for (i = 0; i < FREQCOUNT; i ++) {
-        float value = log(out[i]);
-        if (finite(value)) {
+        if (out[i] > 0) {
+            float value = log(out[i]);
             chan->sum[i] += value;
             chan->profilecount[i] ++;
         }
@@ -182,8 +182,8 @@ int st_noiseprof_stop(eff_t effp)
     int i;
 
     for (i = 0; i < effp->ininfo.channels; i ++) {
-        chandata_t* chan = &(data->chandata[i]);
         int j;
+        chandata_t* chan = &(data->chandata[i]);
 
         fprintf(data->output_file, "Channel %d: ", i);
 
