@@ -19,8 +19,8 @@ extern "C" {
 #include <stdlib.h>
 #include "ststdint.h"
 
-/* Release 12.17.7 of libst */
-#define ST_LIB_VERSION_CODE 0x0c1107
+/* Release 12.17.9 of libst */
+#define ST_LIB_VERSION_CODE 0x0c1109
 #define ST_LIB_VERSION(a,b,c) (((a) << 16) + ((b) << 8) + (c))
 
 typedef int32_t st_sample_t;
@@ -67,10 +67,11 @@ typedef uint32_t st_rate_t;
 
 typedef struct  st_signalinfo
 {
-    st_rate_t rate;      /* sampling rate */
-    char size;           /* word length of data */
-    char encoding;       /* format of sample numbers */
-    char channels;       /* number of sound channels */
+    st_rate_t rate;       /* sampling rate */
+    signed char size;     /* word length of data */
+    signed char encoding; /* format of sample numbers */
+    signed char channels; /* number of sound channels */
+    char swap;            /* do byte- or word-swap */
 } st_signalinfo_t;
 
 /* Loop parameters */
@@ -80,7 +81,7 @@ typedef struct  st_loopinfo
     st_size_t    start;          /* first sample */
     st_size_t    length;         /* length */
     unsigned int count;          /* number of repeats, 0=forever */
-    char         type;           /* 0=no, 1=forward, 2=forward/back */
+    signed char  type;           /* 0=no, 1=forward, 2=forward/back */
 } st_loopinfo_t;
 
 /* Instrument parameters */
@@ -92,7 +93,7 @@ typedef struct  st_instrinfo
     char MIDInote;       /* for unity pitch playback */
     char MIDIlow, MIDIhi;/* MIDI pitch-bend range */
     char loopmode;       /* semantics of loop data */
-    char nloops;         /* number of active loops (max ST_MAX_NLOOPS) */
+    signed char nloops;  /* number of active loops (max ST_MAX_NLOOPS) */
 } st_instrinfo_t;
 
 /* Loop modes, upper 4 bits mask the loop blass, lower 4 bits describe */
@@ -148,7 +149,9 @@ struct st_soundstream {
     st_loopinfo_t   loops[ST_MAX_NLOOPS]; /* Looping specification */
     char            swap;                 /* do byte- or word-swap */
     char            seekable;             /* can seek on this file */
-    st_size_t       length; /* estimate of total samples in file - for seeking*/
+    char            mode;                 /* read or write mode */
+    /* Total samples per channel of file.  Zero if unknown. */
+    st_size_t       length;    
     char            *filename;            /* file name */
     char            *filetype;            /* type of file */
     char            *comment;             /* comment string */
@@ -174,6 +177,7 @@ extern st_format_t st_formats[];
 #define ST_FILE_LOOPS   2  /* does file format support loops? */
 #define ST_FILE_INSTR   4  /* does file format support instrument specs? */
 #define ST_FILE_SEEK    8  /* does file format support seeking? */
+#define ST_FILE_NOSTDIO 16 /* does not use stdio routines */
 
 /* Size field */
 #define ST_SIZE_BYTE    1
@@ -199,10 +203,12 @@ extern st_format_t st_formats[];
 #define ST_ENCODING_INV_ULAW    9 /* Inversed bit-order u-law */
 #define ST_ENCODING_INV_ALAW    10/* Inversed bit-order A-law */
 #define ST_ENCODING_MP3         11/* MP3 compression */
-#define ST_ENCODING_MAX         11 
+#define ST_ENCODING_VORBIS      12/* Vorbis compression */
+#define ST_ENCODING_MAX         12 
 
 /* declared in misc.c */
 extern const char *st_sizes_str[];
+extern const char *st_size_bits_str[];
 extern const char *st_encodings_str[];
 
 #define ST_EFF_CHAN     1               /* Effect can mix channels up/down */
@@ -249,22 +255,29 @@ struct st_effect
 
 extern st_effect_t st_effects[]; /* declared in handlers.c */
 
+extern ft_t st_open_read(const char *path, const st_signalinfo_t *info, 
+                         const char *filetype);
+extern ft_t st_open_write(const char *path, const st_signalinfo_t *info,
+                          const char *filetype, const char *comment);
+extern ft_t st_open_write_instr(const char *path, const st_signalinfo_t *info,
+                                const char *filetype, const char *comment, 
+                                const st_instrinfo_t *instr,
+                                const st_loopinfo_t *loops);
+extern st_ssize_t st_read(ft_t ft, st_sample_t *buf, st_ssize_t len);
+extern st_ssize_t st_write(ft_t ft, st_sample_t *buf, st_ssize_t len);
+extern int st_close(ft_t ft);
+
+#define ST_SEEK_SET 0
+extern int st_seek(ft_t ft, st_size_t offset, int whence);
+
 int st_geteffect_opt(eff_t, int, char **);
 int st_geteffect(eff_t, char *);
 int st_checkeffect(char *);
 int st_updateeffect(eff_t, st_signalinfo_t *in, st_signalinfo_t *out, int);
 int st_gettype(ft_t);
 ft_t st_initformat(void);
-void st_copyformat(ft_t, ft_t);
-int st_checkformat(ft_t);
 int st_parsesamples(st_rate_t rate, char *str, st_size_t *samples, char def);
 
-/* FIXME: Recording hacks shouldn't display a "sigint" style interface.
- * Instead we should provide a function to call when done playing/recording.
- * sox.c should be responsible for registering to sigint.
- */
-void sigintreg(ft_t);
-
 /* FIXME: these declared in util.c, global is inappropriate for lib */
 extern int verbose;     /* be noisy on stderr */
 extern char *myname;
@@ -282,6 +295,7 @@ const char *st_version(void);                   /* return version number */
 #define ST_EPERM 2004           /* Operation not permitted */
 #define ST_ENOTSUP 2005         /* Operation not supported */
 #define ST_EINVAL 2006          /* Invalid argument */
+#define ST_EFFMT 2007           /* Unsupported file format */
 
 #ifdef __cplusplus
 } /* end of extern "C" */
